@@ -264,6 +264,36 @@ def process_members():
     exporter.generate_report()
 
 
+@click.command()
+@click.argument("member_id")
+@transaction.atomic()
+def process_member(member_id):
+    """Process a member"""
+    SAMPLES_BUCKET = "samples-crossref-research"
+    SAMPLES_PATH = "members-works/sample-2023-01-21/works/"
+
+    ANNOTATION_BUCKET = "outputs.research.crossref.org"
+    ANNOTATION_PATH = "annotations"
+    ANNOTATION_FILENAME = "preservation.json"
+
+    CODE_BUCKET = "airflow-crossref-research-annotation"
+
+    PARALLEL_JOBS = 5
+
+    import exporter
+
+    exporter.process_sample(
+        ANNOTATION_BUCKET,
+        ANNOTATION_FILENAME,
+        ANNOTATION_PATH,
+        SAMPLES_BUCKET,
+        SAMPLES_PATH,
+        member_id,
+        CODE_BUCKET,
+        verbose=True,
+    )
+
+
 @click.command()
 @click.argument("issn")
 @transaction.atomic()
@@ -444,6 +474,7 @@ if __name__ == "__main__":
     cli.add_command(import_ocul)
     cli.add_command(import_pkp)
     cli.add_command(import_portico)
+    cli.add_command(process_member)
     cli.add_command(process_members)
     cli.add_command(random_samples)
     cli.add_command(show_archives)
