@@ -2,6 +2,8 @@ from preservationdatabase.models import (
     CarinianaPreservation,
     ClockssPreservation,
     HathiPreservation,
+    InternetArchivePreservation,
+    InternetArchiveItem,
     LockssPreservation,
     OculScholarsPortalPreservation,
     PKPPreservation,
@@ -12,6 +14,8 @@ archives = {
     "cariniana": CarinianaPreservation,
     "clockss": ClockssPreservation,
     "hathitrust": HathiPreservation,
+    "internet_archive": InternetArchivePreservation,
+    "internet_archive_scholar": InternetArchiveItem,
     "lockss": LockssPreservation,
     "pkp": PKPPreservation,
     "portico": PorticoPreservation,
