@@ -139,10 +139,10 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
     one_archive = 0
 
     for sample_item in samples:
-        overall_status["about"]["member"] = sample_item["member"]
-
         result = json.loads(sample_item)["data-point"]
 
+        overall_status["about"]["member"] = result["member"]
+
         # we can only work with journal articles
         # we exclude journal articles from the current year because they
         # most likely have not been ingested into digital preservation
@@ -205,6 +205,22 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
                     two_archives += 1
                 elif archive_count > 2:
                     three_archives += 1
+        else:
+            # this is an excluded sample item
+            if "type" in result and result["type"] != "journal-article":
+                overall_status["excluded-non-journal"] += 1
+                if verbose:
+                    logging.info(
+                        f"{result['DOI']} is excluded as it is not a journal "
+                        f"article"
+                    )
+
+            elif date.today().year == result["published"]["date-parts"][0][0]:
+                overall_status["excluded-current-year"] += 1
+                if verbose:
+                    logging.info(
+                        f"{result['DOI']} is excluded as is too recent"
+                    )
 
     # add blank keys for archives that weren't used
     for preservation_system, class_o in archives.items():
