@@ -1096,7 +1096,7 @@ class InternetArchivePreservation(models.Model):
             return None, False
 
         # We add a single IA entry per volume
-        pi = preserved_item.filter(preserved_volume=str(volume))
+        pi = preserved_item.filter(preserved_volumes=str(volume))
 
         if pi.count() > 0:
             return pi, pi.preserved
