@@ -65,6 +65,7 @@ def show_preservation(
     archive: str = None,
     year: str | None = None,
     no_issn: bool = False,
+    verbose: bool = False,
 ) -> (dict | None, str):
     """
     Determine whether an item is preserved
@@ -75,6 +76,7 @@ def show_preservation(
     :param doi: the DOI
     :param no_issn: if true, will not look up ISSNs for expansion
     :param year: the year
+    :param verbose: if true, will print status updates
     :param archive: the archive to query (or None for all archives)
     :return: a dictionary of preservations and a doi
     """
@@ -89,7 +91,7 @@ def show_preservation(
     else:
         final_issn_list = expand_issns(issn)
 
-    if issn != final_issn_list:
+    if issn != final_issn_list and verbose:
         logging.info(
             f"Expanded ISSN list for title from {issn} to {final_issn_list}"
         )
